package cn.iocoder.yudao.module.jx.service;


import cn.iocoder.yudao.module.jx.domain.DriveSchoolFacility;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import java.util.List;

/**
 * 设备管理Service接口
 *
 * @author ruoyi
 * @date 2024-05-23
 */
public interface IDriveSchoolFacilityService
{
    /**
     * 查询设备管理
     *
     * @param id 设备管理主键
     * @return 设备管理
     */
    public DriveSchoolFacility selectDriveSchoolFacilityById(Long id);

    /**
     * 查询设备管理列表
     *
     * @param driveSchoolFacility 设备管理
     * @return 设备管理集合
     */
    public IPage<DriveSchoolFacility> selectDriveSchoolFacilityList(DriveSchoolFacility driveSchoolFacility, Page<DriveSchoolFacility> page);

    /**
     * 新增设备管理
     *
     * @param driveSchoolFacility 设备管理
     * @return 结果
     */
    public int insertDriveSchoolFacility(DriveSchoolFacility driveSchoolFacility);

    /**
     * 修改设备管理
     *
     * @param driveSchoolFacility 设备管理
     * @return 结果
     */
    public int updateDriveSchoolFacility(DriveSchoolFacility driveSchoolFacility);

    /**
     * 批量删除设备管理
     *
     * @param ids 需要删除的设备管理主键集合
     * @return 结果
     */
    public int deleteDriveSchoolFacilityByIds(Long[] ids);

    /**
     * 删除设备管理信息
     *
     * @param id 设备管理主键
     * @return 结果
     */
    public int deleteDriveSchoolFacilityById(Long id);
}
